@@ -1,8 +1,8 @@
 import os
 import sys
-from typing import Optional, Tuple
+from typing import Optional
 
-from dataclasses import dataclass, fields, field
+from dataclasses import field
 from ai_harness import harnessutils as aiutils
 from transformers import HfArgumentParser
 
@@ -74,9 +74,13 @@ class DataArguments:
                     "than this will be truncated, sequences shorter will be padded."
         },
     )
+    predict: bool = field(
+        default=False, metadata={"help": "Overwrite the cached training and evaluation sets"}
+    )
     overwrite_cache: bool = field(
         default=False, metadata={"help": "Overwrite the cached training and evaluation sets"}
     )
+    progress_bar: bool = field(default=False, metadata={"help": "Whether shows the progress_bar"})
 
 
 @dataclass
